@@ -1,5 +1,4 @@
 from dataclasses import field
-from typing import Optional
 
 from pydantic.dataclasses import dataclass
 
@@ -12,7 +11,7 @@ from metaphor.snowflake.utils import DEFAULT_THREAD_POOL_SIZE
 class SnowflakeRunConfig(SnowflakeAuthConfig):
 
     # Include or exclude specific databases/schemas/tables
-    filter: Optional[DatasetFilter] = field(default_factory=lambda: DatasetFilter())
+    filter: DatasetFilter = field(default_factory=lambda: DatasetFilter())
 
     # Max number of concurrent queries to database
-    max_concurrency: Optional[int] = DEFAULT_THREAD_POOL_SIZE
+    max_concurrency: int = DEFAULT_THREAD_POOL_SIZE
